@@ -1,6 +1,5 @@
 const St = imports.gi.St;
 const Gio = imports.gi.Gio;
-const Lang = imports.lang;
 const DEFAULT_SPEED = 0.75;
 const ExtensionUtils = imports.misc.extensionUtils;
 const Extension = ExtensionUtils.getCurrentExtension();
@@ -8,7 +7,6 @@ const Settings = Extension.imports.settings;
 
 function LOG(m){
 	global.log("[impatience] " + m);
-	log("[impatience] " + m);
 };
 function Ext() {
 	this._init.apply(this, arguments);
@@ -18,21 +16,22 @@ var noop = function() {};
 Ext.prototype = {};
 Ext.prototype._init = function() {
 	this.enabled = false;
-	this.original_speed = St.get_slow_down_factor();
+	this.original_speed = St.Settings.get().slow_down_factor;
 	this.modified_speed = DEFAULT_SPEED;
 	this.unbind = noop;
 };
 
 Ext.prototype.enable = function() {
+	var self = this;
 	this.enabled = true;
 	var pref = (new Settings.Prefs()).SPEED;
 	LOG("enabled");
-	var binding = pref.changed(Lang.bind(this, function() {
-		this.set_speed(pref.get());
-	}));
+	var binding = pref.changed(function() {
+		self.set_speed(pref.get());
+	});
 	this.unbind = function() {
 		pref.disconnect(binding);
-		this.unbind = noop;
+		self.unbind = noop;
 	};
 	this.set_speed(pref.get());
 };
@@ -40,7 +39,7 @@ Ext.prototype.enable = function() {
 Ext.prototype.disable = function() {
 	this.enabled = false;
 	this.unbind();
-	St.set_slow_down_factor(this.original_speed);
+	St.Settings.get().slow_down_factor = this.original_speed;
 };
 
 Ext.prototype.set_speed = function(new_speed) {
@@ -52,7 +51,7 @@ Ext.prototype.set_speed = function(new_speed) {
 		this.modified_speed = new_speed;
 	}
 	LOG("setting new speed: " + this.modified_speed);
-	St.set_slow_down_factor(this.modified_speed);
+	St.Settings.get().slow_down_factor = this.modified_speed;
 };
 
 function init() {
